@@ -1,5 +1,5 @@
 # The SGE Specification
-# Written in 2012, 2013, 2014 by Julian Marchant <onpon4@riseup.net> 
+# Written in 2012, 2013, 2014, 2015 by Julian Marchant <onpon4@riseup.net> 
 # 
 # To the extent possible under law, the author(s) have dedicated all
 # copyright and related and neighboring rights to this software to the
@@ -112,8 +112,7 @@ class Room(object):
 
     def start(self, transition=None, transition_time=1500):
         """
-        Start the room, resetting to its original state if it has been
-        started previously.
+        Start the room.
 
         Arguments:
 
@@ -144,14 +143,6 @@ class Room(object):
         """
         # TODO
 
-    def resume(self, transition=None, transition_time=1500):
-        """
-        Start the room without resetting to its original state if it has
-        been started previously.  See the documentation for
-        :meth:`sge.Room.start` for more information.
-        """
-        # TODO
-
     def project_dot(self, x, y, z, color):
         """
         Project a single-pixel dot onto the room.
@@ -286,8 +277,8 @@ class Room(object):
         # TODO
 
     def project_text(self, font, text, x, y, z, width=None, height=None,
-                    color=sge.Color("black"), halign=sge.ALIGN_LEFT,
-                    valign=sge.ALIGN_TOP, anti_alias=True):
+                    color=sge.Color("black"), halign="left",
+                    valign="top", anti_alias=True):
         """
         Project text onto the room.
 
@@ -306,19 +297,18 @@ class Room(object):
 
     def event_room_start(self):
         """
-        Called when the room starts for the first time, and when it is
-        restarted with :meth:`sge.Room.start`.  It is always called
-        after any :meth:`sge.Game.event_game_start` and before any
-        :class:`sge.Object.event_create` occurring at the same time.
+        Called when the room is started for the first time.  It is
+        always called after any :meth:`sge.Game.event_game_start` and
+        before any :class:`sge.Object.event_create` occurring at the
+        same time.
         """
         pass
 
     def event_room_resume(self):
         """
-        Called when the room is resumed with :meth:`sge.Room.resume`
-        after it has already previously been started.  It is always
-        called before any :meth:`sge.Object.event_create` occurring at
-        the same time.
+        Called when the room is started after it has already previously
+        been started.  It is always called before any
+        :meth:`sge.Object.event_create` occurring at the same time.
         """
         pass
 
@@ -339,7 +329,7 @@ class Room(object):
 
     def event_alarm(self, alarm_id):
         """
-        See the documentation for :meth:`sge.Room.alarms` for more
+        See the documentation for :attr:`sge.Room.alarms` for more
         information.
         """
         pass
@@ -454,6 +444,13 @@ class Room(object):
         """
         pass
 
+    def event_paused_step(self, time_passed, delta_mult):
+        """
+        See the documentation for :meth:`sge.Game.event_step` for more
+        information.
+        """
+        pass
+
     def event_paused_key_press(self, key, char):
         """
         See the documentation for :class:`sge.input.KeyPress` for more
